Spatialize landscape metric values
spatialize_lsm(
landscape,
level = "patch",
metric = NULL,
name = NULL,
type = NULL,
what = NULL,
directions = 8,
progress = FALSE,
to_disk = getOption("to_disk", default = FALSE),
...
)list
Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
Level of metrics. Either 'patch', 'class' or 'landscape' (or vector with combination).
Abbreviation of metrics (e.g. 'area').
Full name of metrics (e.g. 'core area')
Type according to FRAGSTATS grouping (e.g. 'aggregation metrics').
Selected level of metrics: either "patch", "class" or "landscape".
It is also possible to specify functions as a vector of strings, e.g. what = c("lsm_c_ca", "lsm_l_ta").
The number of directions in which patches should be connected: 4 (rook's case) or 8 (queen's case).
Print progress report.
If TRUE raster will be saved to disk.
Arguments passed on to calculate_lsm().
The functions returns a nested list with RasterLayers. The first level
contains each input layer (only one element if RasterLayer was provided).
The second level contains a RasterLayer for each selected metric
(see list_lsm for details) where each cell has the landscape metric
value of the patch it belongs to. Only patch level metrics are allowed.
list_lsm
show_lsm
spatialize_lsm(landscape, what = "lsm_p_area")
Run the code above in your browser using DataLab